# -*- coding: utf-8 -*-
from setuphelpers import *

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()
{
   "key":"Input Director",
   "name":"Input Director v2.2 ",
   "version":"2.2",
   "install_date":"",
   "install_location":"\"C:\\Program Files\\Input Director\"",
   "uninstall_string":"\"C:\\Program Files\\Input Director\\uninstall.exe\"",
   "publisher":"Imperative Software Pty Ltd",
   "system_component":0,
   "win64":false
  }

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls


def install():
    # Declaring local variables
    bin_name = glob.glob("InputDirector.*.exe")[0]

    # Installing the software

    install_exe_if_needed(
        bin_name,
        silentflags="/S /allusers",
        key="Input Director",
        min_version=control.get_software_version(),
    )
    uninstallkey.clear()


def uninstall():
    # Force uninstalling the software
    for to_uninstall in installed_softwares(name="Input Director"):
        print("Removing: %s (%s)" % (to_uninstall["name"], to_uninstall["version"]))
        killalltasks(ensure_list(control.impacted_process))

        try:
            # Adding silent flags to the uninstall command
            uninstall_command = uninstall_cmd(to_uninstall["key"]) + " /S /allusers"
            run(uninstall_command)
            wait_uninstallkey_absent(to_uninstall["key"], max_loop=60)
        except Exception as e:
            print(f"Error during uninstallation: {e}")
            # Handling the case where Input Director might already be partially uninstalled
            print("Input Director might have already been uninstalled.")
            print("Removing Input Director from the list of installed programs.")

        if uninstall_key_exists(to_uninstall["key"]):
            unregister_uninstall(to_uninstall["key"], win64app=to_uninstall["win64"])

        # Clean up any remaining files
        if isdir(to_uninstall["install_location"]):
            print(f"Removing remaining files in {to_uninstall['install_location']}")
            remove_tree(to_uninstall["install_location"])
